# Set path and clear relevant variables
setwd("...PATH...")
if (exists("OI_Raw")) {rm(OI_Raw)}

# Read data
OI_Raw <- read.table("OI_Commands_Preprocessed.dat",header = TRUE, sep="\t")
names(OI_Raw)

# Clean up data by filtering out bad items and by removing Subject 104 and 
# the corresponding yoked participant according to feedback from the 
# experimenter.
OI_Raw <- OI_Raw[OI_Raw$tfilter==1,]
OI_Raw <- OI_Raw[OI_Raw$Subject!=104,]
OI_Raw <- OI_Raw[OI_Raw$Subject!=204,]

# Center predictor variables
OI_Raw$Phase1_Performed <- OI_Raw$Phase1_Performed - 0.5
OI_Raw$Phase2_Present <- OI_Raw$Phase2_Present - 0.5

# Divide data sets according to experiment
OI_Command <- OI_Raw[as.numeric(as.character(OI_Raw$Subject))<200,]
OI_Observe <- OI_Raw[as.numeric(as.character(OI_Raw$Subject))>200,]


# Run analyses
require(lme4)


# Experiment 1

# Fit the saturated model including the interaction term (_IA), the main effects model (_ME),
# and the null model (_Null) with random effects for participant and item
command_IA <- glmer(OI_Command$YesIDid ~ OI_Command$Phase1_Performed * 
                                         OI_Command$Phase2_Present + 
                                        (1|OI_Command$Subject) + (1|OI_Command$Item),
                                         family=binomial(link="logit"))
command_ME <- glmer(OI_Command$YesIDid ~ OI_Command$Phase1_Performed + 
                                         OI_Command$Phase2_Present + 
                                        (1|OI_Command$Subject) + (1|OI_Command$Item),
                                         family=binomial(link="logit"))
command_Null <- glmer(OI_Command$YesIDid ~ (1|OI_Command$Subject),family=binomial(link="logit"))

# Evaluate need for interaction term
summary(command_IA)
ia_evidence <- AIC(command_ME)-AIC(command_IA)
print(ia_evidence)
anova(command_ME,command_IA)

# Drop interaction and use main effects model
anova(command_Null,command_ME)
summary(command_ME)

#Delta AIC
AIC(command_Null)-AIC(command_ME)

# get log odds
logoddsME <- summary(command_ME)
logoddsMEcoefs <- logoddsME$coefficients
# read logistic distribution
plogis(logoddsMEcoefs[,1])
plogis(sum(logoddsMEcoefs[,1]))

#cis
round(logoddsMEcoefs[,1]-qnorm(0.975)*logoddsMEcoefs[,2],2)
round(logoddsMEcoefs[,1]+qnorm(0.975)*logoddsMEcoefs[,2],2)


# Experiment 2

# Fit the saturated model including the interaction term (_IA), the main effects model (_ME),
# and the null model (_Null) with random effects for participant and item
observe_IA <- glmer(OI_Observe$YesIDid ~ OI_Observe$Phase1_Performed * 
                      OI_Observe$Phase2_Present + 
                      (1|OI_Observe$Subject) + (1|OI_Observe$Item),
                    family=binomial(link="logit"))
observe_ME <- glmer(OI_Observe$YesIDid ~ OI_Observe$Phase1_Performed + 
                      OI_Observe$Phase2_Present + 
                      (1|OI_Observe$Subject) + (1|OI_Observe$Item),
                    family=binomial(link="logit"))
observe_Null <- glmer(OI_Observe$YesIDid ~ (1|OI_Observe$Subject),family=binomial(link="logit"))

# Evaluate need for interaction term
summary(observe_IA)
ia_evidence <- AIC(observe_ME)-AIC(observe_IA)
print(ia_evidence)
anova(observe_ME,observe_IA)

# Drop interaction and use main effects model
anova(observe_Null,observe_ME)
summary(observe_ME)

#Delta AIC
AIC(observe_Null)-AIC(observe_ME)

# get log odds
logoddsME <- summary(observe_ME)
logoddsMEcoefs <- logoddsME$coefficients
# read logistic distribution
plogis(logoddsMEcoefs[,1])
plogis(sum(logoddsMEcoefs[,1]))

#cis
round(logoddsMEcoefs[,1]-qnorm(0.975)*logoddsMEcoefs[,2],2)
round(logoddsMEcoefs[,1]+qnorm(0.975)*logoddsMEcoefs[,2],2)



# Group comparison

alltheOI_ME <- glmer(OI_Raw$YesIDid ~ OI_Raw$Phase1_Performed + OI_Raw$Phase2_Present + OI_Raw$Group + (1|OI_Raw$Subject),family=binomial(link="logit"))
alltheOI_IA <- glmer(OI_Raw$YesIDid ~ OI_Raw$Phase1_Performed * OI_Raw$Phase2_Present + OI_Raw$Group + (1|OI_Raw$Subject),family=binomial(link="logit"))
alltheOI_null <- glmer(OI_Raw$YesIDid ~ OI_Raw$Group + (1|OI_Raw$Subject),family=binomial(link="logit"))
print(alltheOI_ME)
summary(alltheOI_ME)


# Model comparisons
anova(alltheOI_null,alltheOI_ME)
anova(alltheOI_ME,alltheOI_IA)


# get log odds
logoddsME3 <- summary(alltheOI_ME)
logoddsME3coefs <- logoddsME3$coefficients
# read logistic distribution
plogis(logoddsME3coefs[,1])
plogis(sum(logoddsME3coefs[,1]))


# log odds
summary(alltheOI_ME)

#cis
round(logoddsME3coefs[,1]-qnorm(0.975)*logoddsME3coefs[,2],2)
round(logoddsME3coefs[,1]+qnorm(0.975)*logoddsME3coefs[,2],2)